#!/usr/bin/awk -f

# genvel3_RTW_ASYMMETRIC.awk
# 
# Miroslav Broz (miroslav.broz@email.cz)

BEGIN{
  au=149597870.e3;
  km=1.e3;
  ms_auday=86400./au;

  v_R_koef = ARGV[1];
  v_T_koef = ARGV[2];
  v_W_koef = ARGV[3];

  ARGV[1]=ARGV[2]=ARGV[3]="";

  OFMT=CONVFMT="%19.16E";
}
(FILENAME==ARGV[4]) && (NF>=3) && !/^#/{
  i++;
  v_R[i]=$1*ms_auday * v_R_koef;
  v_T[i]=$2*ms_auday * v_T_koef;
  v_W[i]=$3*ms_auday * v_W_koef;
}
(FILENAME==ARGV[5]) && !/^#/{
  j++;
  s[j]=$0;
}
END{
  n=i;
  m=j;

  # lines in pl.in file
  J = 6 
  split(s[3*J+0],R);
  split(s[3*J+1],V);

  normalize(R,n_R);
  cross_product(R,V,W);
  normalize(W,n_W)
  cross_product(n_W,n_R,n_T);

  # shift (in n_R) due to proximity of the massive body!
  delta = 1000.*km/au;

  print n;
  for (i=1; i<=n; i++) {
    print " " R[1] + delta*n_R[1], R[2]+delta*n_R[2], R[3]+delta*n_R[3];
    print " " V[1] + v_R[i]*n_R[1] + v_T[i]*n_T[1] + v_W[i]*n_W[1],
              V[2] + v_R[i]*n_R[2] + v_T[i]*n_T[2] + v_W[i]*n_W[2],
              V[3] + v_R[i]*n_R[3] + v_T[i]*n_T[3] + v_W[i]*n_W[3];
    print "0";
    print "0.0";
  }
}


func normalize(r,n) {
  norm = sqrt(r[1]**2 + r[2]**2 + r[3]**2);
  n[1] = r[1]/norm;
  n[2] = r[2]/norm;
  n[3] = r[3]/norm;
  return;
}

func cross_product(a,b,c) {
  c[1] = a[2]*b[3]-a[3]*b[2];
  c[2] = a[3]*b[1]-a[1]*b[3];
  c[3] = a[1]*b[2]-a[2]*b[1];
  return;
}


